/*
 * Copyright 2005-2009 Lukas Blunschi
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package ch.ethz.cisd.hotdeploy;

import java.io.IOException;
import java.io.InputStream;
import java.net.MalformedURLException;
import java.net.URL;
import java.net.URLClassLoader;
import java.util.zip.ZipEntry;
import java.util.zip.ZipFile;

/**
 * This URL class loader keeps references to an open Zip file which allows to
 * close it afterwards. It is very important to close Zip files otherwise
 * strange things may happen!
 * 
 * @author Lukas Blunschi
 */
final class ClosableURLClassLoader extends URLClassLoader
{
    private String path;

    private ZipFile file;

    public ClosableURLClassLoader(String path, ClassLoader parent) throws MalformedURLException
    {
        super(new URL[]
            { new URL("file:" + path) }, parent);
        this.path = path;
    }

    @Override
    public InputStream getResourceAsStream(String name)
    {
        try
        {
            file = new ZipFile(path);
            ZipEntry entry = file.getEntry(name.startsWith("/") ? name.substring(1) : name);
            if (entry == null)
            {
                file.close();
                file = null;
                return null;
            } else
            {
                // remember opened file
                return file.getInputStream(entry);
            }
        } catch (Exception e)
        {
            e.printStackTrace();
            return null;
        }
    }

    /** Close references to opened zip file (via getResourceAsStream) */
    public void close()
    {
        if (file != null)
        {
            try
            {
                file.close();
            } catch (IOException e)
            {
            }
        }
        file = null;
    }

}
