/*
 * Copyright 2012 ETH Zuerich, CISD
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package ch.ethz.cisd.hotdeploy;

import java.io.File;
import java.util.ArrayList;
import java.util.List;

/**
 * A class that holds all configuration parameters for a {@link PluginContainer}
 * 
 * @author Bernd Rinn
 */
public final class PluginContainerParameters
{
    // default: 10s
    private long scanIntervalMillis = 10000L;

    private List<File> pluginDirs = new ArrayList<File>();

    private boolean runGCOnShutdown;

    private boolean requirePluginInfo;

    long getScanIntervalMillis()
    {
        return scanIntervalMillis;
    }

    /**
     * The scan interval in milliseconds.
     */
    public PluginContainerParameters scanIntervalMillis(@SuppressWarnings("hiding")
    long scanIntervalMillis)
    {
        this.scanIntervalMillis = scanIntervalMillis;
        return this;
    }

    /**
     * Disables periodic re-scans.
     */
    public PluginContainerParameters noPeriodicScan()
    {
        this.scanIntervalMillis = -1;
        return this;
    }

    List<File> getPluginDirs()
    {
        return pluginDirs;
    }

    public PluginContainerParameters addPluginDir(
            File pluginDir)
    {
        this.pluginDirs.add(pluginDir);
        return this;
    }

    boolean isRunGCOnShutdown()
    {
        return runGCOnShutdown;
    }

    public PluginContainerParameters runGCOnShutdown(@SuppressWarnings("hiding")
    boolean runGCOnShutdown)
    {
        this.runGCOnShutdown = runGCOnShutdown;
        return this;
    }

    public PluginContainerParameters runGCOnShutdown()
    {
        this.runGCOnShutdown = true;
        return this;
    }

    boolean isRequirePluginInfo()
    {
        return requirePluginInfo;
    }

    public PluginContainerParameters requirePluginInfo()
    {
        this.requirePluginInfo = true;
        return this;
    }

    public PluginContainerParameters requirePluginInfo(@SuppressWarnings("hiding")
    boolean requirePluginInfo)
    {
        this.requirePluginInfo = requirePluginInfo;
        return this;
    }

}
