/*
 * Copyright 2012 ETH Zuerich, CISD
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package ch.ethz.cisd.hotdeploy;

import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

/**
 * An annotation to tag a class as a plugin in the hotdeployment framework. May be used instead (or
 * together with) {@link Plugin}.
 * 
 * @author Bernd Rinn
 */
@Retention(RetentionPolicy.RUNTIME)
@Target(ElementType.TYPE)
public @interface PluginInfo
{
    /**
     * The type of the plugin. Should be the worker interface that this plugin can be casted to.
     */
    Class<?> pluginType();

    /**
     * A (user-readable) name for the plugin. Should be unique with the plugins of the same
     * {@link #pluginType()}.
     */
    String name();
    
    /**
     * The major version of this plugin.
     */
    int majorVersion() default 1;
    
    /**
     * The minor version of this plugin.
     */
    int minorVersion() default 0;

}
